package tsmq

import (
	"log"
	"time"
  "encoding/json"

	"tsm/config"
	"tsm/mqtt"

	"github.com/beevik/ntp"
)

type variable_t struct {
  Name string `json:"variable"`
  Value float64 `json:"value"`
  Unit string `json:"unit"`
  Status string `json:"status"`
}

type message_t struct {
  Server string `json:"server"`
  Label string `json:"label"`
  Variables map[string]variable_t `json:"variables"`
}



func Start() {
	for {
    for _, server := range config.Config.Servers {
      log.Println("Polling server " + server.Name)

      message := message_t {
        Server: server.Name,
        Label: server.Label,
        Variables: make(map[string]variable_t),
      }
        
      label := "rootdisp"
      status := "Ok"
      value := 0.0
      resp, err := ntp.Query(server.Name)
      if err != nil {
        status = "Error"
      } else {
        value = resp.RootDispersion.Seconds() * 1000
      }

      v := variable_t {
        Name: label,
        Value: value,
        Unit: "ms",
        Status: status,
      }
      message.Variables[label] = v


      j, err := json.Marshal(message)
      if err != nil {
        log.Printf("Unable to marshal message, it is lost: %s, %v", message, err)
      } else {
        mqtt.Publish(j)
      }
    }

		time.Sleep(time.Duration(config.Config.Interval) * time.Second)
	}
}

func Stop() {
}
